<?PHP
//	PWDL:        " PHP WebDevelopment Library "
//	Autor:       " Oliver Keller "
//  Name:        " Younik Network " 
//  Reference:   " http://www.younik.net " 
//	Date:        " 12.04.2006 "
//	Version:     " Revision 1.1 " 
	
	
	/*	pdfHandler - Class overview:
	 *		- show_file()					// shows pdf-file in the browser
	 *		- make_file(string)				// filename, makes pdf-file for download
	 *	
	 *		- put_text(string)
	 *		- vspace (integer)
	 *		- new_page()
	 *
	 *		- make_top_line()
	 *		- make_bottom_line(string*) 	// comment
	 *
	 *		- set_font(string)				// Times-Roman / Courier / Helvetica
	 *		- set_weight(string)	
	 *		- set_text_size(integer)
	 *		- set_align(string)				// left / center / right 
	 *		- set_img_align(string)			// left / center / right
	 *	
	 *		- add_image(string, string*)	// filepath, offset to left border (works only, if image alignment is set to left)
	 *		- put_link(string, string)		// target, text
	 *		
	 *		
	 *	the pdf class is working with the php-pdf-classes by:
	 *	Wayne Munro, R&OS Ltd, http://www.ros.co.nz/pdf
	 */
	 
	 
	//	include pdf classes by wayne munro
	include('class.report.php');
	
	
	class pdfHandler {
	
	//	initialization		-----------------------------------------------------------------------------
	
		function pdfHandler() {
			$this->get_path();
			$this->default_settings();
			$this->create();
		}
				
		
	//	action		-----------------------------------------------------------------------------
		
		function create() {
			$this->pdf = new Creport('a4', 'portrait');
			$this->pdf->ezSetMargins(60,70,60,60);
			$this->pdf->selectFont($this->font_path.$this->font.$this->font_weight.".afm");
		}
				
		function put_text($text) {
			$this->pdf->ezText($text, $this->text_size, array('justification'=>$this->align));
		}

		function vspace($space) {
			if (is_int($space)) {
				$this->pdf->ezSetDy(-$space);
			}
		}

		function new_page() {
			$this->pdf->ezNewPage();
		}
		
		
	//	output		-----------------------------------------------------------------------------
		
		function get_data() {
			return $this->pdf->ezOutput();
		}
		
		function show_file() {
			header("Content-type: application/pdf");
			$this->print_file("file.pdf");
		}

		function make_file($filename) {
			header("Content-type: application/octet-stream");
			$this->print_file($filename);
			exit();
		}
		
		function print_file($filename) {
			header("Content-Disposition: inline; filename=".$filename);
			echo $this->pdf->ezOutput();
		}
		
								
	//	utilities		-----------------------------------------------------------------------------
		
		function make_bottom_line($comment='') {
			$this->all_bottom = $this->pdf->openObject();
			$this->pdf->saveState();
			$this->pdf->setStrokeColor(0,0,0,1);
			$this->pdf->line(20,40,578,40);
			$this->pdf->addText(60,28,9, $comment);
			$this->pdf->restoreState();
			$this->pdf->closeObject();
			$this->pdf->addObject($this->all_bottom,'all');
		}
				
		function make_top_line() {
			$this->all_top = $this->pdf->openObject();
			$this->pdf->saveState();
			$this->pdf->setStrokeColor(0,0,0,1);
			$this->pdf->line(20,812,578,812);
			$this->pdf->restoreState();
			$this->pdf->closeObject();
			$this->pdf->addObject($this->all_top,'all');
		}
		
		function get_path() {
			$this->font_path = "no font path";
			if (file_exists('pwdl/lib/fonts/Times-Roman.afm')) 				{ $this->font_path = "pwdl/lib/fonts/";	} 
			elseif (file_exists('../pwdl/lib/fonts/Times-Roman.afm')) 		{ $this->font_path = "../pwdl/lib/fonts/";	} 
			elseif (file_exists('../../pwdl/lib/fonts/Times-Roman.afm')) 	{ $this->font_path = "../../pwdl/lib/fonts/";	} 
			elseif (file_exists('../../../pwdl/lib/fonts/Times-Roman.afm')) { $this->font_path = "../../../pwdl/lib/fonts/";	} 
		}

		
	//	images		-----------------------------------------------------------------------------
		
		function add_image($image_path, $x_offset=0) {
			if (file_exists($image_path)){
				$padding = 30;
				$font_height = $this->pdf->getFontHeight($this->pdf->ez['fontSize']);
				$point_pos   = strpos($font_height, ".");
				$this->vspace(substr($font_height,0,$point_pos) * 2 - 20);
				if ($this->img_align == "left" && $x_offset > 500) { $x_offset = 500; }
				elseif ($this->img_align == "center") { $x_offset = -30; }
				elseif ($this->img_align == "right")  { $x_offset = -60; }
				
				@$this->pdf->ezImage($image_path, $padding, $width=0, $resize='no', $just=$this->img_align, $border='', $x_offset-$padding);
			}
		}
						
		
	//	hyperlinks		-----------------------------------------------------------------------------

		function put_link($target, $text) {
			$this->put_text("<c:alink:http://".$target.">".$text."</c:alink>");
		}

		
	//	settings		-----------------------------------------------------------------------------

		function default_settings() {
			$this->font = "Times-Roman";
			$this->align = "left";
			$this->text_size = "12";
			$this->font_weight = "";
			$this->img_align = "left";
		}
				
		function set_font($font) {
			if ($font == "Times-Roman" || $font == "Courier" || $font == "Helvetica") {
				$this->font = $font;
			}
			$this->pdf->selectFont($this->font_path.$this->font.$this->font_weight.".afm");
		}
		
		function set_weight($weight) {
			if (strtolower($weight) == "bold") {
				$this->font_weight = "-Bold";
			} else {
				$this->font_weight = "";
			}
			$this->pdf->selectFont($this->font_path.$this->font.$this->font_weight.".afm");
		}
		
		function set_align($align) {
			if ($align == "left" || $align == "right" || $align == "center") {
				$this->align = $align;
			}
		}
		
		function set_text_size($size) {
			if (is_int($size)) {
				$this->text_size = $size;
			}
		}
		
		function set_img_align($align) {
			if ($align == "right" || $align == "center" || $align == "left") {
				$this->img_align = $align;
			}
		}
	}
?>